==> hipCUB-6.1.1.tar.gz: hipCUB-rocm-6.1.1/hipcub/include/hipcub/backend/rocprim/device/device_memcpy.hpp <==
/******************************************************************************
 * Copyright (c) 2011-2022, NVIDIA CORPORATION. All rights reserved.
 * Modifications Copyright (c) 2023, Advanced Micro Devices, Inc.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *     * Neither the name of the NVIDIA CORPORATION nor the
 *       names of its contributors may be used to endorse or promote products
 *       derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL NVIDIA CORPORATION BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 ******************************************************************************/

#ifndef HIPCUB_ROCPRIM_DEVICE_DEVICE_MEMCPY_HPP_
#define HIPCUB_ROCPRIM_DEVICE_DEVICE_MEMCPY_HPP_

#include "../../../config.hpp"

#include <rocprim/device/device_memcpy.hpp>

#include <hip/hip_runtime.h>

BEGIN_HIPCUB_NAMESPACE

struct DeviceMemcpy
{
    template<typename InputBufferIt, typename OutputBufferIt, typename BufferSizeIteratorT>
    static hipError_t Batched(void*               d_temp_storage,
                              size_t&             temp_storage_bytes,
                              InputBufferIt       input_buffer_it,
                              OutputBufferIt      output_buffer_it,
                              BufferSizeIteratorT buffer_sizes,
                              uint32_t            num_buffers,
                              hipStream_t         stream            = 0,
                              bool                debug_synchronous = false)
    {
        return rocprim::batch_memcpy(d_temp_storage,
                                     temp_storage_bytes,
                                     input_buffer_it,
                                     output_buffer_it,
                                     buffer_sizes,
                                     num_buffers,
                                     stream,
                                     debug_synchronous);
    }
};

END_HIPCUB_NAMESPACE

#endif // HIPCUB_ROCPRIM_DEVICE_DEVICE_MEMCPY_HPP_

==> hipCUB-7.0.2.tar.gz: hipCUB-rocm-7.0.2/hipcub/include/hipcub/backend/rocprim/device/device_memcpy.hpp <==
/******************************************************************************
 * Copyright (c) 2011-2022, NVIDIA CORPORATION. All rights reserved.
 * Modifications Copyright (c) 2023-2025, Advanced Micro Devices, Inc.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *     * Neither the name of the NVIDIA CORPORATION nor the
 *       names of its contributors may be used to endorse or promote products
 *       derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL NVIDIA CORPORATION BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 ******************************************************************************/

#ifndef HIPCUB_ROCPRIM_DEVICE_DEVICE_MEMCPY_HPP_
#define HIPCUB_ROCPRIM_DEVICE_DEVICE_MEMCPY_HPP_

#include "../../../config.hpp"

#include <rocprim/device/device_memcpy.hpp> // IWYU pragma: export

#include <hip/hip_runtime.h>

BEGIN_HIPCUB_NAMESPACE

struct DeviceMemcpy
{
    template<typename InputBufferIt, typename OutputBufferIt, typename BufferSizeIteratorT>
    static hipError_t Batched(void*               d_temp_storage,
                              size_t&             temp_storage_bytes,
                              InputBufferIt       input_buffer_it,
                              OutputBufferIt      output_buffer_it,
                              BufferSizeIteratorT buffer_sizes,
                              uint32_t            num_buffers,
                              hipStream_t         stream = 0)
    {
        return rocprim::batch_memcpy(d_temp_storage,
                                     temp_storage_bytes,
                                     input_buffer_it,
                                     output_buffer_it,
                                     buffer_sizes,
                                     num_buffers,
                                     stream,
                                     HIPCUB_DETAIL_DEBUG_SYNC_VALUE);
    }
};

END_HIPCUB_NAMESPACE

#endif // HIPCUB_ROCPRIM_DEVICE_DEVICE_MEMCPY_HPP_
